[![Contributors][contributors-shield]][contributors-url]
[![Forks][forks-shield]][forks-url]
[![Stargazers][stars-shield]][stars-url]
[![Issues][issues-shield]][issues-url]
[![MIT License][license-shield]][license-url]
[![LinkedIn][linkedin-shield]][linkedin-url]

<br />
<div align="center">
  <a href="https://github.com/kevocde/selenium-loader">
    <img src="docs/assets/logo.png" alt="Logo" width="100" height="100">
  </a>
  <h2 align="center">Selenium Loader</h2>
  <p align="center">
    A simple way to define your route to automate task with <strong>Selenium</strong> via descriptive <strong>YML</strong> configuration.
    <br />
    <a href="https://github.com/kevocde/selenium-loader"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    <a href="https://kevocde.github.io/selenium-loader" target="_blank">View Demo</a>
    ·
    <a href="https://github.com/kevocde/selenium-loader/issues">Report Bug</a>
    ·
    <a href="https://github.com/kevocde/selenium-loader/issues">Request Feature</a>
  </p>
</div>

### About The Project
A simple way to declarate explicitly the steps to automate a task with Selenium, using a YML configuration file.
You just need to define the steps to automate a task, and the Selenium Loader will do the rest.

### Built with

### Getting Started
#### Prerequisites
#### Installation

### License
Distributed under the MIT License. See `LICENSE.txt` file for more information.
See more about this in [Apache License, Version 2.0](https://opensource.org/license/apache-2-0/).

[contributors-shield]: https://img.shields.io/github/contributors/kevocde/selenium-loader.svg?style=for-the-badge
[contributors-url]: https://github.com/kevocde/selenium-loader/graphs/contributors
[forks-shield]: https://img.shields.io/github/forks/kevocde/selenium-loader.svg?style=for-the-badge
[forks-url]: https://github.com/kevocde/selenium-loader/network/members
[stars-shield]: https://img.shields.io/github/stars/kevocde/selenium-loader.svg?style=for-the-badge
[stars-url]: https://github.com/kevocde/selenium-loader/stargazers
[issues-shield]: https://img.shields.io/github/issues/kevocde/selenium-loader.svg?style=for-the-badge
[issues-url]: https://github.com/kevocde/selenium-loader/issues
[license-shield]: https://img.shields.io/github/license/kevocde/selenium-loader.svg?style=for-the-badge&logo=mit
[license-url]: https://github.com/kevocde/selenium-loader/blob/main/LICENSE.txt
[linkedin-shield]: https://img.shields.io/badge/-LinkedIn-black.svg?style=for-the-badge&logo=linkedin&colorB=555
[linkedin-url]: https://www.linkedin.com/in/kevocode